==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/gl.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Vde. activou a autenticación TOTP de dous factores para a súa conta",
    "You disabled TOTP two-factor authentication for your account" : "Vde. desactivou a autenticación TOTP de dous factores para a súa conta",
    "TOTP (Authenticator app)" : "TOTP (aplicación de autenticación)",
    "Authenticate with a TOTP app" : "Autenticar coa aplicación TOTP",
    "Two-Factor TOTP Provider" : "Provedor TOTP de dous factores",
    "Enable TOTP" : "Activar TOTP",
    "Could not enable TOTP" : "Non foi posíbel activar TOTP ",
    "Could not verify your key. Please try again" : "Non foi posíbel verificar a súa chave. Ténteo de novo",
    "Your new TOTP secret is:" : "O seu novo segredo de TOTP é:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para unha configuración rápida, escanee este código QR coa súa aplicación TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Após configurar a súa aplicación, introduza deseguido un código de proba para asegurar que todo funcione correctamente:",
    "Authentication code" : "Código de autenticación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obteña o código de autenticación da aplicación de autenticación de dous factores no seu dispositivo.",
    "Submit" : "Enviar",
    "TOTP two-factor authentication disabled by an admin" : "A autenticación TOTP de dous factores foi desactivada por un administrador.",
    "TOTP two-factor provider" : "Provedor de autenticación de dous factores TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Un provedor de segundo factor de autenticación para TOTP (RFC 6238) "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/twofactor_totp/l10n/gl.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Vde. activou a autenticación TOTP de dous factores para a súa conta",
    "You disabled TOTP two-factor authentication for your account" : "Vde. desactivou a autenticación TOTP de dous factores para a súa conta",
    "TOTP two-factor authentication disabled by the administration" : "A autenticación TOTP de dous factores foi desactivada pola administración.",
    "TOTP (Authenticator app)" : "TOTP (aplicación de autenticación)",
    "Authenticate with a TOTP app" : "Autenticar coa aplicación TOTP",
    "Two-Factor TOTP Provider" : "Provedor TOTP de dous factores",
    "Two-factor TOTP provider" : "Provedor TOTP de dous factores",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Un provedor de segundo factor de autenticación para TOTP (RFC 6238) ",
    "Could not enable TOTP" : "Non foi posíbel activar TOTP ",
    "Could not verify your key. Please try again" : "Non foi posíbel verificar a súa chave. Ténteo de novo",
    "Enable TOTP" : "Activar TOTP",
    "Your new TOTP secret is:" : "O seu novo segredo de TOTP é:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para unha configuración rápida, escanee este código QR coa súa aplicación TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Após configurar a súa aplicación, introduza deseguido un código de proba para asegurar que todo funcione correctamente:",
    "Authentication code" : "Código de autenticación",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obteña o código de autenticación da aplicación de autenticación de dous factores no seu dispositivo.",
    "Submit" : "Enviar"
},
"nplurals=2; plural=(n != 1);");
